/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2018.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#pragma once

/**
 * @brief       The namespace visuVTK supplies a  default plugin implementation for the visuVTK bundle.
 *
 */
namespace visuVTK
{
}
